@@ -1,7 +1,9 @@
 # -*- coding: utf-8 -*-
+"""for unit-testing"""
 
 from django.conf.urls import patterns, url
-import views
+
+from coop_cms.apps.test_app import views
 
 urlpatterns = patterns('', 
     url(r'^/coop-cms-testclass/$', views.TestClassListView.as_view(), name='coop_cms_testapp_list'),
@@ -9,7 +11,4 @@ urlpatterns = patterns('',
     url(r'^/works/(?P<pk>\d+)/$', views.TestClassDetailView.as_view(), name='coop_cms_testapp_detail'),
     url(r'^/works/cms_edit/$', views.TestClassFormsetEditView.as_view(), name='coop_cms_testapp_formset_edit'),
     url(r'^/works/$', views.TestClassFormsetView.as_view(), name='coop_cms_testapp_formset'),
-    
-    
-    
-)
\ No newline at end of file
+)
